==> aliyun-java-sdk-kms-2.7.0-sources.jar: com/aliyuncs/kms/model/v20160120/ImportKeyMaterialRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.kms.model.v20160120;

import com.aliyuncs.RpcAcsRequest;
import com.aliyuncs.http.ProtocolType;
import com.aliyuncs.kms.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class ImportKeyMaterialRequest extends RpcAcsRequest<ImportKeyMaterialResponse> {
	
	public ImportKeyMaterialRequest() {
		super("Kms", "2016-01-20", "ImportKeyMaterial", "kms");
		setProtocol(ProtocolType.HTTPS);
		try {
			this.getClass().getDeclaredField("ProductEndpointMap").set(this, Endpoint.endpointMap);
			this.getClass().getDeclaredField("ProductEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	private String importToken;

	private String encryptedKeyMaterial;

	private Long keyMaterialExpireUnix;

	private String keyId;

	public String getImportToken() {
		return this.importToken;
	}

	public void setImportToken(String importToken) {
		this.importToken = importToken;
		if(importToken != null){
			putQueryParameter("ImportToken", importToken);
		}
	}

	public String getEncryptedKeyMaterial() {
		return this.encryptedKeyMaterial;
	}

	public void setEncryptedKeyMaterial(String encryptedKeyMaterial) {
		this.encryptedKeyMaterial = encryptedKeyMaterial;
		if(encryptedKeyMaterial != null){
			putQueryParameter("EncryptedKeyMaterial", encryptedKeyMaterial);
		}
	}

	public Long getKeyMaterialExpireUnix() {
		return this.keyMaterialExpireUnix;
	}

	public void setKeyMaterialExpireUnix(Long keyMaterialExpireUnix) {
		this.keyMaterialExpireUnix = keyMaterialExpireUnix;
		if(keyMaterialExpireUnix != null){
			putQueryParameter("KeyMaterialExpireUnix", keyMaterialExpireUnix.toString());
		}
	}

	public String getKeyId() {
		return this.keyId;
	}

	public void setKeyId(String keyId) {
		this.keyId = keyId;
		if(keyId != null){
			putQueryParameter("KeyId", keyId);
		}
	}

	@Override
	public Class<ImportKeyMaterialResponse> getResponseClass() {
		return ImportKeyMaterialResponse.class;
	}

}

==> aliyun-java-sdk-kms-2.10.1-sources.jar: com/aliyuncs/kms/model/v20160120/ImportKeyMaterialRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.kms.model.v20160120;

import com.aliyuncs.RpcAcsRequest;
import com.aliyuncs.http.ProtocolType;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.kms.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class ImportKeyMaterialRequest extends RpcAcsRequest<ImportKeyMaterialResponse> {
	   

	private String importToken;

	private String encryptedKeyMaterial;

	private Long keyMaterialExpireUnix;

	private String keyId;
	public ImportKeyMaterialRequest() {
		super("Kms", "2016-01-20", "ImportKeyMaterial", "kms");
		setProtocol(ProtocolType.HTTPS);
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public String getImportToken() {
		return this.importToken;
	}

	public void setImportToken(String importToken) {
		this.importToken = importToken;
		if(importToken != null){
			putQueryParameter("ImportToken", importToken);
		}
	}

	public String getEncryptedKeyMaterial() {
		return this.encryptedKeyMaterial;
	}

	public void setEncryptedKeyMaterial(String encryptedKeyMaterial) {
		this.encryptedKeyMaterial = encryptedKeyMaterial;
		if(encryptedKeyMaterial != null){
			putQueryParameter("EncryptedKeyMaterial", encryptedKeyMaterial);
		}
	}

	public Long getKeyMaterialExpireUnix() {
		return this.keyMaterialExpireUnix;
	}

	public void setKeyMaterialExpireUnix(Long keyMaterialExpireUnix) {
		this.keyMaterialExpireUnix = keyMaterialExpireUnix;
		if(keyMaterialExpireUnix != null){
			putQueryParameter("KeyMaterialExpireUnix", keyMaterialExpireUnix.toString());
		}
	}

	public String getKeyId() {
		return this.keyId;
	}

	public void setKeyId(String keyId) {
		this.keyId = keyId;
		if(keyId != null){
			putQueryParameter("KeyId", keyId);
		}
	}

	@Override
	public Class<ImportKeyMaterialResponse> getResponseClass() {
		return ImportKeyMaterialResponse.class;
	}

}
